# Venny4Py
Simple Venn diagrams for Python 3, up to 4 sets (for more than 4 sets it is better to use UpSet plot).

For troubleshooting and instructions plese refer to the: https://github.com/timyerg/Venny4Py

